spoon.spoon.lazyprop

Package spoon :: Module spoon :: Class lazyprop |
[hide private]
[frames] | no frames]

# Class lazyprop

source code

    object --+
             |
      property --+
                 |
                lazyprop

When used like a property in a Serial class, it will act as a flag to the serializer that only properties that are of type `serialprop` or `lazyprop` are to be serialized.

Any subclass of this will be treated the same way, so if you need your property to behave like a customizable property, then subclass away.

lazyprop indicates that on decoding, the object will have to explicitly decode all of the properties marked with lazyprop. lazyprop and serialprop may be mixed together in a class, and all serialprops will be decoded.

Instance Methods | [hide private]
`` | __init__(self, value=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
`` | __get__(self, obj, Type=None)
`` | __set__(self, obj, value)
`` | __del__(self, obj)
Inherited from `property`: `__delete__`, `__getattribute__`, `__new__` Inherited from `object`: `__delattr__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `property`: `fdel`, `fget`, `fset`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, value=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: property.__init__ (inherited documentation)

### __get__(self, obj, Type=None) | source code
    Returns:
        value
Overrides: property.__get__ (inherited documentation)

### __set__(self, obj, value) | source code
Overrides: property.__set__ (inherited documentation)

### __del__(self, obj) (Destructor) | source code
None